@@ -1,6 +1,6 @@
-use docker_api::{tty::TtyChunk, Docker};
 use futures::StreamExt;
-use std::{env, str};
+use docker_api::{tty::TtyChunk, Docker};
+use std::env;
 
 #[tokio::main]
 async fn main() -> Result<(), Box<dyn std::error::Error>> {
@@ -25,12 +25,8 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
 
 fn print_chunk(chunk: TtyChunk) {
     match chunk {
-        TtyChunk::StdOut(bytes) => {
-            println!("Stdout: {}", str::from_utf8(&bytes).unwrap_or_default())
-        }
-        TtyChunk::StdErr(bytes) => {
-            eprintln!("Stdout: {}", str::from_utf8(&bytes).unwrap_or_default())
-        }
+        TtyChunk::StdOut(bytes) => println!("Stdout: {}", std::str::from_utf8(&bytes).unwrap()),
+        TtyChunk::StdErr(bytes) => eprintln!("Stdout: {}", std::str::from_utf8(&bytes).unwrap()),
         TtyChunk::StdIn(_) => unreachable!(),
     }
 }
