@@ -1,11 +1,11 @@
-use docker_api::Docker;
 use futures::TryStreamExt;
+use docker_api::Docker;
 use std::{env, path};
 use tar::Archive;
 
 #[tokio::main]
 async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     let id = env::args()
         .nth(1)
         .expect("Usage: cargo run --example containercopyfrom -- <container> <path in container>");
