@@ -2,8 +2,8 @@ use docker_api::Docker;
 use std::{env, fs::File, io::Read};
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+async fn main() {
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     let path = env::args()
         .nth(1)
         .expect("Usage: cargo run --example containercopyinto -- <local path> <container>");
@@ -11,7 +11,7 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
         .nth(2)
         .expect("Usage: cargo run --example containercopyinto -- <local path> <container>");
 
-    let mut file = File::open(&path)?;
+    let mut file = File::open(&path).unwrap();
     let mut bytes = Vec::new();
     file.read_to_end(&mut bytes)
         .expect("Cannot read file on the localhost.");
@@ -24,6 +24,4 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
     {
         eprintln!("Error: {}", e)
     }
-
-    Ok(())
 }
