@@ -2,8 +2,8 @@ use docker_api::{ContainerOptions, Docker};
 use std::env;
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+async fn main() {
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     let image = env::args()
         .nth(1)
         .expect("You need to specify an image name");
@@ -16,6 +16,4 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
         Ok(info) => println!("{:?}", info),
         Err(e) => eprintln!("Error: {}", e),
     }
-
-    Ok(())
 }
