@@ -1,10 +1,10 @@
-use docker_api::{tty::TtyChunk, Docker, ExecContainerOptions};
 use futures::StreamExt;
-use std::{env, str};
+use docker_api::{tty::TtyChunk, Docker, ExecContainerOptions};
+use std::{env, str::from_utf8};
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+async fn main() {
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     let id = env::args()
         .nth(1)
         .expect("You need to specify a container id");
@@ -26,18 +26,12 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
             Err(e) => eprintln!("Error: {}", e),
         }
     }
-
-    Ok(())
 }
 
 fn print_chunk(chunk: TtyChunk) {
     match chunk {
-        TtyChunk::StdOut(bytes) => {
-            println!("Stdout: {}", str::from_utf8(&bytes).unwrap_or_default())
-        }
-        TtyChunk::StdErr(bytes) => {
-            eprintln!("Stdout: {}", str::from_utf8(&bytes).unwrap_or_default())
-        }
+        TtyChunk::StdOut(bytes) => println!("Stdout: {}", from_utf8(&bytes).unwrap()),
+        TtyChunk::StdErr(bytes) => eprintln!("Stdout: {}", from_utf8(&bytes).unwrap()),
         TtyChunk::StdIn(_) => unreachable!(),
     }
 }
