@@ -1,9 +1,9 @@
 use docker_api::Docker;
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
+async fn main() {
     env_logger::init();
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     match docker.containers().list(&Default::default()).await {
         Ok(containers) => {
             for c in containers {
@@ -12,6 +12,4 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
         }
         Err(e) => eprintln!("Error: {}", e),
     }
-
-    Ok(())
 }
