@@ -1,9 +1,9 @@
-use docker_api::Docker;
 use futures::StreamExt;
+use docker_api::Docker;
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+async fn main() {
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     println!("listening for events");
 
     while let Some(event_result) = docker.events(&Default::default()).next().await {
@@ -12,6 +12,4 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
             Err(e) => eprintln!("Error: {}", e),
         }
     }
-
-    Ok(())
 }
