@@ -1,10 +1,10 @@
-use docker_api::{Docker, Exec, ExecContainerOptions};
 use futures::StreamExt;
+use docker_api::{Docker, Exec, ExecContainerOptions};
 use std::env;
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+async fn main() {
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     let mut args = env::args().skip(1);
 
     // First argument is container id
@@ -20,15 +20,13 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
         .attach_stderr(true)
         .build();
 
-    let exec = Exec::create(&docker, &id, &opts).await?;
+    let exec = Exec::create(&docker, &id, &opts).await.unwrap();
 
-    println!("{:#?}", exec.inspect().await?);
+    println!("{:#?}", exec.inspect().await.unwrap());
 
     let mut stream = exec.start();
 
     stream.next().await;
 
-    println!("{:#?}", exec.inspect().await?);
-
-    Ok(())
+    println!("{:#?}", exec.inspect().await.unwrap());
 }
