@@ -4,14 +4,15 @@ use std::{env, fs::OpenOptions, io::Write};
 use docker_api::{errors::Error, Docker};
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+async fn main() {
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     let id = env::args().nth(1).expect("You need to specify an image id");
 
     let mut export_file = OpenOptions::new()
         .write(true)
         .create(true)
-        .open(format!("{}.tar", &id))?;
+        .open(format!("{}.tar", &id))
+        .unwrap();
 
     while let Some(export_result) = docker.images().get(&id).export().next().await {
         match export_result.and_then(|bytes| export_file.write(&bytes).map_err(Error::from)) {
@@ -19,6 +20,4 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
             Err(e) => eprintln!("Error: {}", e),
         }
     }
-
-    Ok(())
 }
