@@ -1,10 +1,10 @@
-use docker_api::{BuildOptions, Docker};
 use futures::StreamExt;
+use docker_api::{BuildOptions, Docker};
 use std::env;
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+async fn main() {
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     let path = env::args().nth(1).expect("You need to specify a path");
 
     let options = BuildOptions::builder(path).tag("docker_api_test").build();
@@ -16,6 +16,4 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
             Err(e) => eprintln!("Error: {}", e),
         }
     }
-
-    Ok(())
 }
