@@ -2,8 +2,8 @@ use docker_api::Docker;
 use std::env;
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+async fn main() {
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     let img = env::args()
         .nth(1)
         .expect("You need to specify an image name");
@@ -15,6 +15,4 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
         }
         Err(e) => eprintln!("Error: {}", e),
     }
-
-    Ok(())
 }
