@@ -1,13 +1,13 @@
 // cargo run --example imagepull busybox
 
-use docker_api::{Docker, PullOptions};
 use futures::StreamExt;
+use docker_api::{Docker, PullOptions};
 use std::env;
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
+async fn main() {
     env_logger::init();
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     let img = env::args()
         .nth(1)
         .expect("You need to specify an image name");
@@ -22,6 +22,4 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
             Err(e) => eprintln!("Error: {}", e),
         }
     }
-
-    Ok(())
 }
