@@ -1,8 +1,8 @@
 use docker_api::Docker;
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+async fn main() {
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     println!("docker images in stock");
 
     let result = docker.images().list(&Default::default()).await;
@@ -20,6 +20,4 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
         }
         Err(e) => eprintln!("Error: {}", e),
     }
-
-    Ok(())
 }
