@@ -1,8 +1,8 @@
 use docker_api::Docker;
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+async fn main() {
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     println!("remote docker images in stock");
 
     match docker.images().search("rust").await {
@@ -13,6 +13,4 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
         }
         Err(e) => eprintln!("Error: {}", e),
     }
-
-    Ok(())
 }
