@@ -4,9 +4,9 @@ use docker_api::{Docker, Image, TagOptions};
 use std::env;
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
+async fn main() {
     env_logger::init();
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     let img = env::args()
         .nth(1)
         .expect("You need to specify an image name");
@@ -24,6 +24,4 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
     if let Err(e) = image.tag(&tag_opts).await {
         eprintln!("Error: {}", e)
     }
-
-    Ok(())
 }
