@@ -1,10 +1,10 @@
-use docker_api::Docker;
 use futures::StreamExt;
+use docker_api::Docker;
 use std::{env, fs::File};
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+async fn main() {
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     let path = env::args()
         .nth(1)
         .expect("You need to specify an image path");
@@ -20,6 +20,4 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
             Err(e) => eprintln!("Error: {}", e),
         }
     }
-
-    Ok(())
 }
