@@ -2,8 +2,8 @@ use docker_api::Docker;
 use std::env;
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+async fn main() {
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     let id = env::args()
         .nth(1)
         .expect("Usage: cargo run --example serviceinspect -- <service>");
@@ -12,6 +12,4 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
         Ok(service) => println!("{:#?}", service),
         Err(e) => eprintln!("Error: {}", e),
     }
-
-    Ok(())
 }
