@@ -1,9 +1,9 @@
 use docker_api::{Docker, ServiceListOptions};
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
+async fn main() {
     env_logger::init();
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     match docker
         .services()
         .list(&ServiceListOptions::builder().enable_status().build())
@@ -16,6 +16,4 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
         }
         Err(e) => eprintln!("Error: {}", e),
     }
-
-    Ok(())
 }
