@@ -1,11 +1,11 @@
 //  cargo run --example stats -- <container>
-use docker_api::Docker;
 use futures::StreamExt;
+use docker_api::Docker;
 use std::env;
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+async fn main() {
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
     let containers = docker.containers();
     let id = env::args()
         .nth(1)
@@ -17,6 +17,4 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
             Err(e) => eprintln!("Error: {}", e),
         }
     }
-
-    Ok(())
 }
