@@ -2,8 +2,8 @@ use docker_api::{Docker, VolumeCreateOptions};
 use std::{collections::HashMap, env};
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let docker = Docker::new("tcp://127.0.0.1:80")?;
+async fn main() {
+    let docker = Docker::new("tcp://127.0.0.1:80").unwrap();
 
     let volume_name = env::args()
         .nth(1)
@@ -25,6 +25,4 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
         Ok(info) => println!("{:?}", info),
         Err(e) => eprintln!("Error: {}", e),
     }
-
-    Ok(())
 }
