@@ -10,6 +10,7 @@ use futures_util::{
     TryStreamExt,
 };
 use hyper::Body;
+use mime::Mime;
 use serde::{Deserialize, Serialize};
 use serde_json::{json, Map, Value};
 use url::form_urlencoded;
@@ -19,7 +20,7 @@ use crate::{
     errors::{Error, Result},
     exec::{Exec, ExecContainerOptions},
     image::ContainerConfig,
-    network::NetworkSettings,
+    network::{NetworkInfo, NetworkSettings},
     transport::Payload,
     tty::{self, Multiplexer as TtyMultiPlexer},
 };
@@ -103,7 +104,7 @@ impl<'docker> Container<'docker> {
                     "/containers/{}/attach?stream=1&stdout=1&stderr=1&stdin=1",
                     self.id
                 ),
-                Payload::empty(),
+                None,
             )
             .await
     }
@@ -116,7 +117,9 @@ impl<'docker> Container<'docker> {
     ///
     /// Api Reference: <https://docs.docker.com/engine/api/v1.41/#operation/ContainerAttach>
     pub async fn attach(&self) -> Result<TtyMultiPlexer<'docker>> {
-        self.attach_raw().await.map(TtyMultiPlexer::new)
+        let tcp_stream = self.attach_raw().await?;
+
+        Ok(TtyMultiPlexer::new(tcp_stream))
     }
 
     /// Returns a set of changes made to the container instance
@@ -164,12 +167,9 @@ impl<'docker> Container<'docker> {
     /// Api Reference: <https://docs.docker.com/engine/api/v1.41/#operation/ContainerStart>
     pub async fn start(&self) -> Result<()> {
         self.docker
-            .post(
-                &format!("/containers/{}/start", self.id)[..],
-                Payload::empty(),
-            )
-            .await
-            .map(|_| ())
+            .post(&format!("/containers/{}/start", self.id)[..], None)
+            .await?;
+        Ok(())
     }
 
     /// Stop the container instance
@@ -184,10 +184,8 @@ impl<'docker> Container<'docker> {
 
             path.push(encoded)
         }
-        self.docker
-            .post(&path.join("?"), Payload::empty())
-            .await
-            .map(|_| ())
+        self.docker.post(&path.join("?"), None).await?;
+        Ok(())
     }
 
     /// Restart the container instance
@@ -201,10 +199,8 @@ impl<'docker> Container<'docker> {
                 .finish();
             path.push(encoded)
         }
-        self.docker
-            .post(&path.join("?"), Payload::empty())
-            .await
-            .map(|_| ())
+        self.docker.post(&path.join("?"), None).await?;
+        Ok(())
     }
 
     /// Kill the container instance
@@ -218,10 +214,8 @@ impl<'docker> Container<'docker> {
                 .finish();
             path.push(encoded)
         }
-        self.docker
-            .post(&path.join("?"), Payload::empty())
-            .await
-            .map(|_| ())
+        self.docker.post(&path.join("?"), None).await?;
+        Ok(())
     }
 
     /// Rename the container instance
@@ -234,10 +228,10 @@ impl<'docker> Container<'docker> {
         self.docker
             .post(
                 &format!("/containers/{}/rename?{}", self.id, query)[..],
-                Payload::empty(),
+                None,
             )
-            .await
-            .map(|_| ())
+            .await?;
+        Ok(())
     }
 
     /// Pause the container instance
@@ -245,12 +239,9 @@ impl<'docker> Container<'docker> {
     /// Api Reference: <https://docs.docker.com/engine/api/v1.41/#operation/ContainerPause>
     pub async fn pause(&self) -> Result<()> {
         self.docker
-            .post(
-                &format!("/containers/{}/pause", self.id)[..],
-                Payload::empty(),
-            )
-            .await
-            .map(|_| ())
+            .post(&format!("/containers/{}/pause", self.id)[..], None)
+            .await?;
+        Ok(())
     }
 
     /// Unpause the container instance
@@ -258,12 +249,9 @@ impl<'docker> Container<'docker> {
     /// Api Reference: <https://docs.docker.com/engine/api/v1.41/#operation/ContainerUnpause>
     pub async fn unpause(&self) -> Result<()> {
         self.docker
-            .post(
-                &format!("/containers/{}/unpause", self.id)[..],
-                Payload::empty(),
-            )
-            .await
-            .map(|_| ())
+            .post(&format!("/containers/{}/unpause", self.id)[..], None)
+            .await?;
+        Ok(())
     }
 
     /// Wait until the container stops
@@ -271,7 +259,7 @@ impl<'docker> Container<'docker> {
     /// Api Reference: <https://docs.docker.com/engine/api/v1.41/#operation/ContainerWait>
     pub async fn wait(&self) -> Result<Exit> {
         self.docker
-            .post_json(format!("/containers/{}/wait", self.id), Payload::empty())
+            .post_json(format!("/containers/{}/wait", self.id), Payload::None)
             .await
     }
 
@@ -283,8 +271,8 @@ impl<'docker> Container<'docker> {
     pub async fn delete(&self) -> Result<()> {
         self.docker
             .delete(&format!("/containers/{}", self.id)[..])
-            .await
-            .map(|_| ())
+            .await?;
+        Ok(())
     }
 
     /// Delete the container instance (todo: force/v)
@@ -295,7 +283,8 @@ impl<'docker> Container<'docker> {
         if let Some(query) = opts.serialize() {
             path.push(query)
         }
-        self.docker.delete(&path.join("?")).await.map(|_| ())
+        self.docker.delete(&path.join("?")).await?;
+        Ok(())
     }
 
     /// Execute a command in this container
@@ -347,10 +336,12 @@ impl<'docker> Container<'docker> {
                 .skip(1)
                 .collect::<std::path::PathBuf>(),
             bytes,
-        )?;
-        let data = ar.into_inner()?;
+        )
+        .unwrap();
+        let data = ar.into_inner().unwrap();
 
-        self.copy_to(Path::new("/"), data.into()).await.map(|_| ())
+        self.copy_to(Path::new("/"), data.into()).await?;
+        Ok(())
     }
 
     /// Copy a tarball (see `body`) to the container.
@@ -363,13 +354,15 @@ impl<'docker> Container<'docker> {
             .append_pair("path", &path.to_string_lossy())
             .finish();
 
+        let mime = "application/x-tar".parse::<Mime>().unwrap();
+
         self.docker
             .put(
                 &format!("/containers/{}/archive?{}", self.id, path_arg),
-                Payload::XTar(body),
+                Some((body, mime)),
             )
-            .await
-            .map(|_| ())
+            .await?;
+        Ok(())
     }
 }
 
@@ -422,11 +415,37 @@ impl<'docker> Containers<'docker> {
         }
 
         self.docker
-            .post_json(&path.join("?"), Payload::Json(body))
+            .post_json(&path.join("?"), Some((body, mime::APPLICATION_JSON)))
             .await
     }
 }
 
+/// Options for filtering container list results
+#[derive(Default, Debug)]
+pub struct ContainerListOptions {
+    params: HashMap<&'static str, String>,
+}
+
+impl ContainerListOptions {
+    /// return a new instance of a builder for options
+    pub fn builder() -> ContainerListOptionsBuilder {
+        ContainerListOptionsBuilder::default()
+    }
+
+    /// serialize options as a string. returns None if no options are defined
+    pub fn serialize(&self) -> Option<String> {
+        if self.params.is_empty() {
+            None
+        } else {
+            Some(
+                form_urlencoded::Serializer::new(String::new())
+                    .extend_pairs(&self.params)
+                    .finish(),
+            )
+        }
+    }
+}
+
 /// Filter options for container listings
 pub enum ContainerFilter {
     ExitCode(u64),
@@ -435,7 +454,11 @@ pub enum ContainerFilter {
     Label(String, String),
 }
 
-impl_url_opts_builder!(ContainerList);
+/// Builder interface for `ContainerListOptions`
+#[derive(Default)]
+pub struct ContainerListOptionsBuilder {
+    params: HashMap<&'static str, String>,
+}
 
 impl ContainerListOptionsBuilder {
     pub fn filter<F>(&mut self, filters: F) -> &mut Self
@@ -454,7 +477,7 @@ impl ContainerListOptionsBuilder {
         // structure is a a json encoded object mapping string keys to a list
         // of string values
         self.params
-            .insert("filters", serde_json::to_string(&param).unwrap_or_default());
+            .insert("filters", serde_json::to_string(&param).unwrap());
         self
     }
 
@@ -483,6 +506,12 @@ impl ContainerListOptionsBuilder {
         self.params.insert("size", "true".to_owned());
         self
     }
+
+    pub fn build(&self) -> ContainerListOptions {
+        ContainerListOptions {
+            params: self.params.clone(),
+        }
+    }
 }
 
 /// Interface for building a new docker container from an existing image
@@ -499,21 +528,21 @@ where
     V: Serialize,
     I: Iterator<Item = &'a str>,
 {
-    if let Some(local_key) = key_path.next() {
-        if key_path.peek().is_some() {
-            if let Some(node) = parent_node.as_object_mut() {
-                let node = node
-                    .entry(local_key.to_string())
-                    .or_insert(Value::Object(Map::new()));
+    let local_key = key_path.next().unwrap();
 
-                insert(key_path, value, node);
-            }
-        } else if let Some(node) = parent_node.as_object_mut() {
-            node.insert(
-                local_key.to_string(),
-                serde_json::to_value(value).unwrap_or_default(),
-            );
-        }
+    if key_path.peek().is_some() {
+        let node = parent_node
+            .as_object_mut()
+            .unwrap()
+            .entry(local_key.to_string())
+            .or_insert(Value::Object(Map::new()));
+
+        insert(key_path, value, node);
+    } else {
+        parent_node
+            .as_object_mut()
+            .unwrap()
+            .insert(local_key.to_string(), serde_json::to_value(value).unwrap());
     }
 }
 
@@ -774,7 +803,37 @@ impl ContainerOptionsBuilder {
     }
 }
 
-impl_url_opts_builder!(Logs);
+/// Options for controlling log request results
+#[derive(Default, Debug)]
+pub struct LogsOptions {
+    params: HashMap<&'static str, String>,
+}
+
+impl LogsOptions {
+    /// return a new instance of a builder for options
+    pub fn builder() -> LogsOptionsBuilder {
+        LogsOptionsBuilder::default()
+    }
+
+    /// serialize options as a string. returns None if no options are defined
+    pub fn serialize(&self) -> Option<String> {
+        if self.params.is_empty() {
+            None
+        } else {
+            Some(
+                form_urlencoded::Serializer::new(String::new())
+                    .extend_pairs(&self.params)
+                    .finish(),
+            )
+        }
+    }
+}
+
+/// Builder interface for `LogsOptions`
+#[derive(Default)]
+pub struct LogsOptionsBuilder {
+    params: HashMap<&'static str, String>,
+}
 
 impl LogsOptionsBuilder {
     pub fn follow(&mut self, f: bool) -> &mut Self {
@@ -818,9 +877,45 @@ impl LogsOptionsBuilder {
         self.params.insert("since", timestamp.to_string());
         self
     }
+
+    pub fn build(&self) -> LogsOptions {
+        LogsOptions {
+            params: self.params.clone(),
+        }
+    }
 }
 
-impl_url_opts_builder!(RmContainer);
+/// Options for controlling log request results
+#[derive(Default, Debug)]
+pub struct RmContainerOptions {
+    params: HashMap<&'static str, String>,
+}
+
+impl RmContainerOptions {
+    /// return a new instance of a builder for options
+    pub fn builder() -> RmContainerOptionsBuilder {
+        RmContainerOptionsBuilder::default()
+    }
+
+    /// serialize options as a string. returns None if no options are defined
+    pub fn serialize(&self) -> Option<String> {
+        if self.params.is_empty() {
+            None
+        } else {
+            Some(
+                form_urlencoded::Serializer::new(String::new())
+                    .extend_pairs(&self.params)
+                    .finish(),
+            )
+        }
+    }
+}
+
+/// Builder interface for `LogsOptions`
+#[derive(Default)]
+pub struct RmContainerOptionsBuilder {
+    params: HashMap<&'static str, String>,
+}
 
 impl RmContainerOptionsBuilder {
     pub fn force(&mut self, f: bool) -> &mut Self {
@@ -832,6 +927,12 @@ impl RmContainerOptionsBuilder {
         self.params.insert("v", s.to_string());
         self
     }
+
+    pub fn build(&self) -> RmContainerOptions {
+        RmContainerOptions {
+            params: self.params.clone(),
+        }
+    }
 }
 
 #[derive(Clone, Debug, Serialize, Deserialize)]
@@ -1078,24 +1179,12 @@ pub struct Port {
 #[derive(Clone, Debug, Serialize, Deserialize)]
 pub struct Stats {
     pub read: String,
-    pub networks: HashMap<String, NetworkStats>,
+    pub networks: HashMap<String, NetworkInfo>,
     pub memory_stats: MemoryStats,
     pub blkio_stats: BlkioStats,
     pub cpu_stats: CpuStats,
 }
 
-#[derive(Clone, Debug, Serialize, Deserialize)]
-pub struct NetworkStats {
-    pub rx_dropped: u64,
-    pub rx_bytes: u64,
-    pub rx_errors: u64,
-    pub tx_packets: u64,
-    pub tx_dropped: u64,
-    pub rx_packets: u64,
-    pub tx_errors: u64,
-    pub tx_bytes: u64,
-}
-
 #[derive(Clone, Debug, Serialize, Deserialize)]
 pub struct MemoryStats {
     pub max_usage: u64,
