@@ -2,21 +2,18 @@
 //!
 //! API Reference: <https://docs.docker.com/engine/api/v1.41/>
 
-use std::{io, path::Path};
+use std::{collections::HashMap, io, path::Path};
 
-use futures_util::{
-    io::{AsyncRead, AsyncWrite},
-    stream::Stream,
-    TryStreamExt,
-};
-use hyper::{body::Bytes, client::HttpConnector, Body, Client, Method};
+use futures_util::{stream::Stream, TryStreamExt};
+use hyper::{client::HttpConnector, Body, Client, Method};
 use log::trace;
-use serde::{de::DeserializeOwned, Deserialize, Serialize};
+use mime::Mime;
+use serde::{de, Deserialize, Serialize};
+use url::form_urlencoded;
 
 use crate::{
     container::Containers,
     errors::{Error, Result},
-    event::{Event, EventsOptions},
     image::Images,
     network::Networks,
     service::Services,
@@ -24,6 +21,8 @@ use crate::{
     volume::Volumes,
 };
 
+#[cfg(feature = "chrono")]
+use crate::datetime::{datetime_from_nano_timestamp, datetime_from_unix_timestamp};
 #[cfg(feature = "chrono")]
 use chrono::{DateTime, Utc};
 
@@ -165,56 +164,45 @@ impl Docker {
         }
     }
 
-    /// Exports an interface for interacting with Docker images
+    /// Exports an interface for interacting with docker images
     pub fn images(&'_ self) -> Images<'_> {
         Images::new(self)
     }
 
-    /// Exports an interface for interacting with Docker containers
+    /// Exports an interface for interacting with docker containers
     pub fn containers(&'_ self) -> Containers<'_> {
         Containers::new(self)
     }
 
-    /// Exports an interface for interacting with Docker services
+    /// Exports an interface for interacting with docker services
     pub fn services(&'_ self) -> Services<'_> {
         Services::new(self)
     }
 
-    /// Exports an interface for interacting with Docker networks
     pub fn networks(&'_ self) -> Networks<'_> {
         Networks::new(self)
     }
 
-    /// Exports an interface for interacting with Docker volumes
     pub fn volumes(&'_ self) -> Volumes<'_> {
         Volumes::new(self)
     }
 
-    /// Returns the version of Docker that is running and various information about the system that
-    /// Docker is running on.
-    ///
-    /// Api Reference: <https://docs.docker.com/engine/api/v1.41/#operation/SystemVersion>
+    /// Returns version information associated with the docker daemon
     pub async fn version(&self) -> Result<Version> {
         self.get_json("/version").await
     }
 
-    /// Returns system information about Docker instance that is running
-    ///
-    /// Api Reference: <https://docs.docker.com/engine/api/v1.41/#operation/SystemInfo>
+    /// Returns information associated with the docker daemon
     pub async fn info(&self) -> Result<Info> {
         self.get_json("/info").await
     }
 
-    /// This is a dummy endpoint you can use to test if the server is accessible.
-    ///
-    /// Api Reference: <https://docs.docker.com/engine/api/v1.41/#operation/SystemPingHead>
+    /// Returns a simple ping response indicating the docker daemon is accessible
     pub async fn ping(&self) -> Result<String> {
         self.get("/_ping").await
     }
 
     /// Returns a stream of docker events
-    ///
-    /// Api Reference: <https://docs.docker.com/engine/api/v1.41/#operation/SystemEvents>
     pub fn events<'docker>(
         &'docker self,
         opts: &EventsOptions,
@@ -240,73 +228,69 @@ impl Docker {
         )
     }
 
-    //####################################################################################################
     //
     // Utility functions to make requests
     //
-    //####################################################################################################
 
     pub(crate) async fn get(&self, endpoint: &str) -> Result<String> {
         self.transport
-            .request(Method::GET, endpoint, Payload::empty(), Headers::none())
+            .request(Method::GET, endpoint, Payload::None, Headers::None)
             .await
     }
 
-    pub(crate) async fn get_json<T: DeserializeOwned>(&self, endpoint: &str) -> Result<T> {
+    pub(crate) async fn get_json<T: serde::de::DeserializeOwned>(
+        &self,
+        endpoint: &str,
+    ) -> Result<T> {
         let raw_string = self
             .transport
-            .request(Method::GET, endpoint, Payload::empty(), Headers::none())
+            .request(Method::GET, endpoint, Payload::None, Headers::None)
             .await?;
         trace!("{}", raw_string);
 
         Ok(serde_json::from_str::<T>(&raw_string)?)
     }
 
-    pub(crate) async fn post<B>(&self, endpoint: &str, body: Payload<B>) -> Result<String>
-    where
-        B: Into<Body>,
-    {
+    pub(crate) async fn post(&self, endpoint: &str, body: Option<(Body, Mime)>) -> Result<String> {
         self.transport
-            .request(Method::POST, endpoint, body, Headers::none())
+            .request(Method::POST, endpoint, body, Headers::None)
             .await
     }
 
-    pub(crate) async fn put<B>(&self, endpoint: &str, body: Payload<B>) -> Result<String>
-    where
-        B: Into<Body>,
-    {
+    pub(crate) async fn put(&self, endpoint: &str, body: Option<(Body, Mime)>) -> Result<String> {
         self.transport
-            .request(Method::PUT, endpoint, body, Headers::none())
+            .request(Method::PUT, endpoint, body, Headers::None)
             .await
     }
 
-    pub(crate) async fn post_json<B, T>(
+    pub(crate) async fn post_json<T, B>(
         &self,
         endpoint: impl AsRef<str>,
-        body: Payload<B>,
+        body: Option<(B, Mime)>,
     ) -> Result<T>
     where
-        T: DeserializeOwned,
+        T: serde::de::DeserializeOwned,
         B: Into<Body>,
     {
         let raw_string = self
             .transport
-            .request(Method::POST, endpoint, body, Headers::none())
+            .request(Method::POST, endpoint, body, Headers::None)
             .await?;
         trace!("{}", raw_string);
 
         Ok(serde_json::from_str::<T>(&&raw_string)?)
     }
 
-    pub(crate) async fn post_json_headers<'a, B, T>(
+    pub(crate) async fn post_json_headers<'a, T, B, H>(
         &self,
         endpoint: impl AsRef<str>,
-        body: Payload<B>,
-        headers: Option<Headers>,
+        body: Option<(B, Mime)>,
+        headers: Option<H>,
     ) -> Result<T>
     where
-        T: DeserializeOwned,
+        T: serde::de::DeserializeOwned,
         B: Into<Body>,
+        H: IntoIterator<Item = (&'static str, String)> + 'a,
     {
         let raw_string = self
             .transport
@@ -319,14 +303,17 @@ impl Docker {
 
     pub(crate) async fn delete(&self, endpoint: &str) -> Result<String> {
         self.transport
-            .request(Method::DELETE, endpoint, Payload::empty(), Headers::none())
+            .request(Method::DELETE, endpoint, Payload::None, Headers::None)
             .await
     }
 
-    pub(crate) async fn delete_json<T: DeserializeOwned>(&self, endpoint: &str) -> Result<T> {
+    pub(crate) async fn delete_json<T: serde::de::DeserializeOwned>(
+        &self,
+        endpoint: &str,
+    ) -> Result<T> {
         let raw_string = self
             .transport
-            .request(Method::DELETE, endpoint, Payload::empty(), Headers::none())
+            .request(Method::DELETE, endpoint, Payload::None, Headers::None)
             .await?;
         trace!("{}", raw_string);
 
@@ -336,28 +323,28 @@ impl Docker {
     /// Send a streaming post request.
     ///
     /// Use stream_post_into_values if the endpoint returns JSON values
-    pub(crate) fn stream_post<'a, B>(
+    pub(crate) fn stream_post<'a, H>(
         &'a self,
         endpoint: impl AsRef<str> + 'a,
-        body: Payload<B>,
-        headers: Option<Headers>,
-    ) -> impl Stream<Item = Result<Bytes>> + 'a
+        body: Option<(Body, Mime)>,
+        headers: Option<H>,
+    ) -> impl Stream<Item = Result<hyper::body::Bytes>> + 'a
     where
-        B: Into<Body> + 'a,
+        H: IntoIterator<Item = (&'static str, String)> + 'a,
     {
         self.transport
             .stream_chunks(Method::POST, endpoint, body, headers)
     }
 
     /// Send a streaming post request.
-    fn stream_json_post<'a, B>(
+    fn stream_json_post<'a, H>(
         &'a self,
         endpoint: impl AsRef<str> + 'a,
-        body: Payload<B>,
-        headers: Option<Headers>,
-    ) -> impl Stream<Item = Result<Bytes>> + 'a
+        body: Option<(Body, Mime)>,
+        headers: Option<H>,
+    ) -> impl Stream<Item = Result<hyper::body::Bytes>> + 'a
     where
-        B: Into<Body> + 'a,
+        H: IntoIterator<Item = (&'static str, String)> + 'a,
     {
         self.transport
             .stream_json_chunks(Method::POST, endpoint, body, headers)
@@ -366,15 +353,15 @@ impl Docker {
     /// Send a streaming post request that returns a stream of JSON values
     ///
     /// When a received chunk does not contain a full JSON reads more chunks from the stream
-    pub(crate) fn stream_post_into<'a, B, T>(
+    pub(crate) fn stream_post_into<'a, H, T>(
         &'a self,
         endpoint: impl AsRef<str> + 'a,
-        body: Payload<B>,
-        headers: Option<Headers>,
+        body: Option<(Body, Mime)>,
+        headers: Option<H>,
     ) -> impl Stream<Item = Result<T>> + 'a
     where
-        B: Into<Body> + 'a,
-        T: DeserializeOwned,
+        H: IntoIterator<Item = (&'static str, String)> + 'a,
+        T: de::DeserializeOwned,
     {
         self.stream_json_post(endpoint, body, headers)
             .and_then(|chunk| async move {
@@ -393,25 +380,157 @@ impl Docker {
     pub(crate) fn stream_get<'a>(
         &'a self,
         endpoint: impl AsRef<str> + Unpin + 'a,
-    ) -> impl Stream<Item = Result<Bytes>> + 'a {
+    ) -> impl Stream<Item = Result<hyper::body::Bytes>> + 'a {
+        let headers = Some(Vec::default());
         self.transport
-            .stream_chunks(Method::GET, endpoint, Payload::empty(), Headers::none())
+            .stream_chunks(Method::GET, endpoint, Option::<(Body, Mime)>::None, headers)
     }
 
-    pub(crate) async fn stream_post_upgrade<'a, B>(
+    pub(crate) async fn stream_post_upgrade<'a>(
         &'a self,
         endpoint: impl AsRef<str> + 'a,
-        body: Payload<B>,
-    ) -> Result<impl AsyncRead + AsyncWrite + 'a>
-    where
-        B: Into<Body> + 'a,
-    {
+        body: Option<(Body, Mime)>,
+    ) -> Result<impl futures_util::io::AsyncRead + futures_util::io::AsyncWrite + 'a> {
         self.transport
             .stream_upgrade(Method::POST, endpoint, body)
             .await
     }
 }
 
+/// Options for filtering streams of Docker events
+#[derive(Default, Debug)]
+pub struct EventsOptions {
+    params: HashMap<&'static str, String>,
+}
+
+impl EventsOptions {
+    pub fn builder() -> EventsOptionsBuilder {
+        EventsOptionsBuilder::default()
+    }
+
+    /// serialize options as a string. returns None if no options are defined
+    pub fn serialize(&self) -> Option<String> {
+        if self.params.is_empty() {
+            None
+        } else {
+            Some(
+                form_urlencoded::Serializer::new(String::new())
+                    .extend_pairs(&self.params)
+                    .finish(),
+            )
+        }
+    }
+}
+
+#[derive(Copy, Clone)]
+pub enum EventFilterType {
+    Container,
+    Image,
+    Volume,
+    Network,
+    Daemon,
+}
+
+fn event_filter_type_to_string(filter: EventFilterType) -> &'static str {
+    match filter {
+        EventFilterType::Container => "container",
+        EventFilterType::Image => "image",
+        EventFilterType::Volume => "volume",
+        EventFilterType::Network => "network",
+        EventFilterType::Daemon => "daemon",
+    }
+}
+
+/// Filter options for image listings
+pub enum EventFilter {
+    Container(String),
+    Event(String),
+    Image(String),
+    Label(String),
+    Type(EventFilterType),
+    Volume(String),
+    Network(String),
+    Daemon(String),
+}
+
+/// Builder interface for `EventOptions`
+#[derive(Default)]
+pub struct EventsOptionsBuilder {
+    params: HashMap<&'static str, String>,
+    events: Vec<String>,
+    containers: Vec<String>,
+    images: Vec<String>,
+    labels: Vec<String>,
+    volumes: Vec<String>,
+    networks: Vec<String>,
+    daemons: Vec<String>,
+    types: Vec<String>,
+}
+
+impl EventsOptionsBuilder {
+    /// Filter events since a given timestamp
+    pub fn since(&mut self, ts: &u64) -> &mut Self {
+        self.params.insert("since", ts.to_string());
+        self
+    }
+
+    /// Filter events until a given timestamp
+    pub fn until(&mut self, ts: &u64) -> &mut Self {
+        self.params.insert("until", ts.to_string());
+        self
+    }
+
+    pub fn filter(&mut self, filters: Vec<EventFilter>) -> &mut Self {
+        let mut params = HashMap::new();
+        for f in filters {
+            match f {
+                EventFilter::Container(n) => {
+                    self.containers.push(n);
+                    params.insert("container", self.containers.clone())
+                }
+                EventFilter::Event(n) => {
+                    self.events.push(n);
+                    params.insert("event", self.events.clone())
+                }
+                EventFilter::Image(n) => {
+                    self.images.push(n);
+                    params.insert("image", self.images.clone())
+                }
+                EventFilter::Label(n) => {
+                    self.labels.push(n);
+                    params.insert("label", self.labels.clone())
+                }
+                EventFilter::Volume(n) => {
+                    self.volumes.push(n);
+                    params.insert("volume", self.volumes.clone())
+                }
+                EventFilter::Network(n) => {
+                    self.networks.push(n);
+                    params.insert("network", self.networks.clone())
+                }
+                EventFilter::Daemon(n) => {
+                    self.daemons.push(n);
+                    params.insert("daemon", self.daemons.clone())
+                }
+                EventFilter::Type(n) => {
+                    let event_type = event_filter_type_to_string(n).to_string();
+                    self.types.push(event_type);
+                    params.insert("type", self.types.clone())
+                }
+            };
+        }
+        self.params
+            .insert("filters", serde_json::to_string(&params).unwrap());
+        self
+    }
+
+    pub fn build(&self) -> EventsOptions {
+        EventsOptions {
+            params: self.params.clone(),
+        }
+    }
+}
+
 #[derive(Clone, Debug, Serialize, Deserialize)]
 #[serde(rename_all = "PascalCase")]
 pub struct Version {
@@ -453,6 +572,38 @@ pub struct Info {
     pub system_time: Option<String>,
 }
 
+#[derive(Clone, Debug, Serialize, Deserialize)]
+pub struct Event {
+    #[serde(rename = "Type")]
+    pub typ: String,
+    #[serde(rename = "Action")]
+    pub action: String,
+    #[serde(rename = "Actor")]
+    pub actor: Actor,
+    pub status: Option<String>,
+    pub id: Option<String>,
+    pub from: Option<String>,
+    #[cfg(feature = "chrono")]
+    #[serde(deserialize_with = "datetime_from_unix_timestamp")]
+    pub time: DateTime<Utc>,
+    #[cfg(not(feature = "chrono"))]
+    pub time: u64,
+    #[cfg(feature = "chrono")]
+    #[serde(deserialize_with = "datetime_from_nano_timestamp", rename = "timeNano")]
+    pub time_nano: DateTime<Utc>,
+    #[cfg(not(feature = "chrono"))]
+    #[serde(rename = "timeNano")]
+    pub time_nano: u64,
+}
+
+#[derive(Clone, Debug, Serialize, Deserialize)]
+pub struct Actor {
+    #[serde(rename = "ID")]
+    pub id: String,
+    #[serde(rename = "Attributes")]
+    pub attributes: HashMap<String, String>,
+}
+
 #[cfg(test)]
 mod tests {
     use super::{Docker, Error};
