@@ -2,18 +2,14 @@
 //!
 //! API Reference: <https://docs.docker.com/engine/api/v1.41/#tag/Image>
 
-use std::{collections::HashMap, io::Read};
+use std::{collections::HashMap, io::Read, iter};
 
 use futures_util::{stream::Stream, TryFutureExt, TryStreamExt};
+use hyper::Body;
 use serde::{Deserialize, Serialize};
 use url::form_urlencoded;
 
-use crate::{
-    docker::Docker,
-    errors::Result,
-    tarball,
-    transport::{Headers, Payload},
-};
+use crate::{docker::Docker, errors::Result, tarball, transport::tar};
 
 #[cfg(feature = "chrono")]
 use crate::datetime::datetime_from_unix_timestamp;
@@ -64,7 +60,7 @@ impl<'docker> Image<'docker> {
     /// Api Reference: <https://docs.docker.com/engine/api/v1.41/#operation/ImagePrune>
     pub async fn delete(&self) -> Result<Vec<Status>> {
         self.docker
-            .delete_json(&format!("/images/{}", self.name)[..])
+            .delete_json::<Vec<Status>>(&format!("/images/{}", self.name)[..])
             .await
     }
 
@@ -87,21 +83,9 @@ impl<'docker> Image<'docker> {
         if let Some(query) = opts.serialize() {
             path.push(query)
         }
-        let _ = self.docker.post(&path.join("?"), Payload::empty()).await?;
+        let _ = self.docker.post(&path.join("?"), None).await?;
         Ok(())
     }
-
-    /// Return image digest and platform information by contacting the registry.
-    ///
-    /// Api Reference: <https://docs.docker.com/engine/api/v1.41/#operation/DistributionInspect>
-    pub async fn distribution_inspect(&self) -> Result<DistributionInspectInfo> {
-        self.docker
-            .post_json(
-                &format!("/distribution/{}/json", self.name),
-                Payload::empty(),
-            )
-            .await
-    }
 }
 
 #[derive(Debug)]
@@ -144,8 +128,8 @@ impl<'docker> Images<'docker> {
 
                 let value_stream = docker.stream_post_into(
                     endpoint.join("?"),
-                    Payload::Tar(bytes),
-                    Headers::none(),
+                    Some((Body::from(bytes), tar())),
+                    None::<iter::Empty<_>>,
                 );
 
                 Ok(value_stream)
@@ -200,12 +184,9 @@ impl<'docker> Images<'docker> {
         }
         let headers = opts
             .auth_header()
-            .map(|a| Headers::single("X-Registry-Auth", a));
+            .map(|a| iter::once(("X-Registry-Auth", a)));
 
-        Box::pin(
-            self.docker
-                .stream_post_into(path.join("?"), Payload::empty(), headers),
-        )
+        Box::pin(self.docker.stream_post_into(path.join("?"), None, headers))
     }
 
     /// exports a collection of named images,
@@ -241,8 +222,8 @@ impl<'docker> Images<'docker> {
 
                 let value_stream = self.docker.stream_post_into(
                     "/images/load",
-                    Payload::Tar(bytes),
-                    Headers::none(),
+                    Some((Body::from(bytes), tar())),
+                    None::<iter::Empty<_>>,
                 );
                 Ok(value_stream)
             }
@@ -291,7 +272,7 @@ impl RegistryAuth {
     pub fn serialize(&self) -> String {
         serde_json::to_string(self)
             .map(|c| base64::encode_config(&c, base64::URL_SAFE))
-            .unwrap_or_default()
+            .unwrap()
     }
 }
 
@@ -338,15 +319,43 @@ impl RegistryAuthBuilder {
 
     pub fn build(&self) -> RegistryAuth {
         RegistryAuth::Password {
-            username: self.username.clone().unwrap_or_default(),
-            password: self.password.clone().unwrap_or_default(),
+            username: self.username.clone().unwrap_or_else(String::new),
+            password: self.password.clone().unwrap_or_else(String::new),
             email: self.email.clone(),
             server_address: self.server_address.clone(),
         }
     }
 }
 
-impl_url_opts_builder!(Tag);
+#[derive(Default, Debug)]
+pub struct TagOptions {
+    pub params: HashMap<&'static str, String>,
+}
+
+impl TagOptions {
+    /// return a new instance of a builder for options
+    pub fn builder() -> TagOptionsBuilder {
+        TagOptionsBuilder::default()
+    }
+
+    /// serialize options as a string. returns None if no options are defined
+    pub fn serialize(&self) -> Option<String> {
+        if self.params.is_empty() {
+            None
+        } else {
+            Some(
+                form_urlencoded::Serializer::new(String::new())
+                    .extend_pairs(&self.params)
+                    .finish(),
+            )
+        }
+    }
+}
+
+#[derive(Default)]
+pub struct TagOptionsBuilder {
+    params: HashMap<&'static str, String>,
+}
 
 impl TagOptionsBuilder {
     pub fn repo<R>(&mut self, r: R) -> &mut Self
@@ -364,6 +373,12 @@ impl TagOptionsBuilder {
         self.params.insert("tag", t.into());
         self
     }
+
+    pub fn build(&self) -> TagOptions {
+        TagOptions {
+            params: self.params.clone(),
+        }
+    }
 }
 
 #[derive(Default, Debug)]
@@ -600,7 +615,34 @@ pub enum ImageFilter {
     Label(String, String),
 }
 
-impl_url_opts_builder!(ImageList);
+/// Options for filtering image list results
+#[derive(Default, Debug)]
+pub struct ImageListOptions {
+    params: HashMap<&'static str, String>,
+}
+
+impl ImageListOptions {
+    pub fn builder() -> ImageListOptionsBuilder {
+        ImageListOptionsBuilder::default()
+    }
+    pub fn serialize(&self) -> Option<String> {
+        if self.params.is_empty() {
+            None
+        } else {
+            Some(
+                form_urlencoded::Serializer::new(String::new())
+                    .extend_pairs(&self.params)
+                    .finish(),
+            )
+        }
+    }
+}
+
+/// Builder interface for `ImageListOptions`
+#[derive(Default)]
+pub struct ImageListOptionsBuilder {
+    params: HashMap<&'static str, String>,
+}
 
 impl ImageListOptionsBuilder {
     pub fn digests(&mut self, d: bool) -> &mut Self {
@@ -636,9 +678,15 @@ impl ImageListOptionsBuilder {
         // structure is a a json encoded object mapping string keys to a list
         // of string values
         self.params
-            .insert("filters", serde_json::to_string(&param).unwrap_or_default());
+            .insert("filters", serde_json::to_string(&param).unwrap());
         self
     }
+
+    pub fn build(&self) -> ImageListOptions {
+        ImageListOptions {
+            params: self.params.clone(),
+        }
+    }
 }
 
 #[derive(Clone, Debug, Serialize, Deserialize)]
@@ -783,23 +831,6 @@ pub struct ProgressDetail {
     pub total: Option<u64>,
 }
 
-#[derive(Serialize, Deserialize, Debug)]
-#[serde(rename_all = "PascalCase")]
-pub struct Descriptor {
-    media_type: String,
-    digest: String,
-    size: u64,
-    #[serde(rename = "URLs")]
-    urls: Vec<String>,
-}
-
-#[derive(Serialize, Deserialize, Debug)]
-#[serde(rename_all = "PascalCase")]
-pub struct DistributionInspectInfo {
-    descriptor: Descriptor,
-    platforms: Vec<serde_json::Value>,
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
